Functional API
==============

.. currentmodule:: jaxsim.api

.. autosummary::
   :toctree: _autosummary

    model
    data
    contact
    kin_dyn_parameters
    joint
    link
    frame
    com
    ode_data
    ode
    references
    common


Model
~~~~~

.. automodule:: jaxsim.api.model
    :members:
    :no-index:

Data
~~~~

.. automodule:: jaxsim.api.data
    :members:
    :no-index:

Contact
~~~~~~~

.. automodule:: jaxsim.api.contact
    :members:
    :no-index:

KinDynParameters
~~~~~~~~~~~~~~~~

.. automodule:: jaxsim.api.kin_dyn_parameters
    :members:
    :no-index:

Joint
~~~~~

.. automodule:: jaxsim.api.joint
    :members:
    :no-index:

Link
~~~~~
.. automodule:: jaxsim.api.link
    :members:
    :no-index:

Frame
~~~~~
.. automodule:: jaxsim.api.frame
    :members:
    :no-index:

CoM
~~~
.. automodule:: jaxsim.api.com
    :members:
    :no-index:

ODE Data
~~~~~~~~

.. automodule:: jaxsim.api.ode_data
    :members:
    :no-index:

.. automodule:: jaxsim.api.ode
    :members:
    :no-index:

References
~~~~~~~~~~

.. automodule:: jaxsim.api.references
    :members:
    :no-index:

Common
~~~~~~

.. autoflag:: jaxsim.api.common.VelRepr
    :members:

.. autoclass:: jaxsim.api.common.ModelDataWithVelocityRepresentation
    :members:
